@@ -230,6 +230,16 @@ MapView::MapView(QWidget* parent) :
   build_context_menu_actions();
 }
 
+/**
+ * @brief Destructor.
+ */
+MapView::~MapView() {
+
+  // Avoid a crash when closing the tab with an active selection.
+  disconnect(scene, &MapScene::selectionChanged,
+             this, &MapView::map_selection_changed);
+}
+
 /**
  * @brief Returns the map represented in this view.
  * @return The map model or nullptr if none was set.
@@ -282,6 +292,9 @@ void MapView::set_map(MapModel* map) {
 
     // Start the state mechanism.
     start_state_doing_nothing();
+
+    connect(scene, &MapScene::selectionChanged,
+            this, &MapView::map_selection_changed);
   }
 }
 
@@ -674,12 +687,9 @@ QMenu* MapView::create_context_menu() {
     // Edit.
     const bool single_selection = indexes.size() <= 1;
     Q_ASSERT(edit_action != nullptr);
-    edit_action->setEnabled(single_selection);
     menu->addAction(edit_action);
 
     // Resize.
-    const bool resizable = are_entities_resizable(indexes);
-    resize_action->setEnabled(resizable);
     menu->addAction(resize_action);
 
     // Direction.
@@ -770,8 +780,6 @@ QMenu* MapView::create_context_menu() {
       menu->addAction(action);
     }
 
-    up_one_layer_action->setEnabled(!has_common_layer || common_layer < get_map()->get_max_layer());
-    down_one_layer_action->setEnabled(!has_common_layer || common_layer > get_map()->get_min_layer());
     menu->addAction(up_one_layer_action);
     menu->addAction(down_one_layer_action);
 
@@ -1060,6 +1068,32 @@ void MapView::mouse_coordinates_changed(const QPoint& xy) {
   emit mouse_map_coordinates_changed(map_xy);
 }
 
+/**
+ * @brief Slot called when the entity selection has changed.
+ *
+ * Updates the availability of actions.
+ */
+void MapView::map_selection_changed() {
+
+  const EntityIndexes& indexes = get_selected_entities();
+
+  if (!indexes.empty()) {
+    const bool single_selection = indexes.size() <= 1;
+
+    Q_ASSERT(edit_action != nullptr);
+    edit_action->setEnabled(single_selection);
+
+    const bool resizable = are_entities_resizable(indexes);
+    Q_ASSERT(resize_action != nullptr);
+    resize_action->setEnabled(resizable);
+
+    int common_layer = -1;
+    bool has_common_layer = map->is_common_layer(indexes, common_layer);
+    up_one_layer_action->setEnabled(!has_common_layer || common_layer < get_map()->get_max_layer());
+    down_one_layer_action->setEnabled(!has_common_layer || common_layer > get_map()->get_min_layer());
+  }
+}
+
 /**
  * @brief Shows or hides the grid according to the view settings.
  */
